<?php

namespace Andy\MembersMap\Pub\Controller;

use XF\Pub\Controller\AbstractController;

class MembersMap extends AbstractController
{	
	public function actionIndex()
	{
		// get visitor
		$visitor = \XF::visitor();				
		
		// check for user group permission
		if (!$visitor->hasPermission('membersMap', 'view'))
		{
			return $this->noPermission();
		}
		
		// get options
		$options = \XF::options();
		
		// get options from Admin CP -> Options -> Members map -> Zoom
		$zoom = $options->membersMapZoom;
		
		// get options from Admin CP -> Options -> Members map -> Coordinates
		$coordinates = $options->membersMapCoordinates;
		
		// get options from Admin CP -> Options -> Members map -> Google key
		$googleKey = $options->membersMapGoogleKey;
		
		// check condition
		if ($googleKey == '')
		{
			return $this->error(\XF::phrase('membersmap_google_key_not_entered_in_options'));
		}
		
		// get coordinatesArray
		$coordinatesArray = explode(",", $coordinates);
		
		// get lat
		$lat = $coordinatesArray[0];
		
		// get lng
		$lng = $coordinatesArray[1];
        
        // get results
        $finder = \XF::finder('Andy\MembersMap:MembersMap');
        $results = $finder->fetch();
		
		// get locations_array
		foreach ($results as $k => $v)
		{
			$locations_array[] = [
				'lat' => $v["lat"] + 0,
				'lng' => $v["lng"] + 0,
				'info' => $v["info"]
			];
		}
		
		// check condition
		if (!empty($locations_array))
		{
			$locationsJson = json_encode($locations_array);
		}
		else
		{
			$locationsJson = array();
		}

		// prepare viewParams
		$viewParams = [
			'zoom' => $zoom,
			'lat' => $lat,
			'lng' => $lng,
			'googleKey' => $googleKey,
			'locationsJson' => $locationsJson
		];
		
		// send to template
		return $this->view('Andy\MembersMap:Index', 'andy_membersmap', $viewParams);
	}
}