<?php

namespace Andy\MembersMap\XF\Cron;

class MembersMap
{
	public static function runMembersMap()
	{
		// get options
		$options = \XF::options();
        
		// get options from Admin CP -> Options -> Members map -> Last activity days
		$lastActivityDays = $options->membersMapLastActivityDays;
		
		// get options from Admin CP -> Options -> Members map -> Add base URL
		$addBaseUrl = $options->membersMapAddBaseUrl;
        
		// get options from Admin CP -> Options -> Members map -> ShowPrivate
		$showPrivate = $options->membersMapShowPrivate;
        
        // check condition
        if ($showPrivate)
        {
            // get phrase
            $phrase = \XF::phrase('private');
        }
        
		// get db
		$db = \XF::db();
	
		// convert to Unix timesatmp
		$timestamp = time() - (86400 * $lastActivityDays);

		// get location
		$location = (isset($_SERVER['HTTPS']) ? "https" : "http") . "://$_SERVER[HTTP_HOST]";
		
		// define variable
		$ipAddress = '';
        
        //########################################
        // truncate tables
        //########################################

        $db->query("
            TRUNCATE TABLE xf_andy_members_map
        ");

        $db->query("
            TRUNCATE TABLE xf_andy_members_map_data
        ");
        
        //########################################
        // get results
        //########################################
	
        // get results1
        $finder = \XF::finder('XF:User');
        $results1 = $finder
            ->where('user_state', 'valid')
            ->where('is_banned', 0)
            ->where('last_activity', '>', $timestamp)
            ->order('user_id', 'ASC')
            ->fetch();

		// foreach condition
		foreach ($results1 AS $value1)
		{  
            // get ip
            $finder = \XF::finder('XF:Ip');
            $result2 = $finder
                ->where('user_id', $value1['user_id'])
                ->order('log_date', 'DESC')
                ->fetchOne();
            
            // check condition
            if (!empty($result2))
            {
                $ip = $result2['ip'];
            }
            
			// check condition
			if (!empty($ip))
			{
				// get ipAddress
				$ipAddress = \XF\Util\Ip::convertIpBinaryToString($ip);

                // check condition
                if (filter_var($ipAddress, FILTER_VALIDATE_IP)) 
                {
                    // define variable
                    $bypass = '';

                    // get url
					$url = 'https://ipapi.co/' . $ipAddress . '/json/';

                    // get response
                    try
                    {
                        $client = \XF::app()->http()->client();
                        $response = $client->get($url);
                    }
                    catch (\GuzzleHttp\Exception\RequestException $e)
                    {
                        $bypass = 'yes';
                    }

                    // check condition
                    if ($bypass != 'yes')
                    {
                        // get array
                        $array = \GuzzleHttp\json_decode($response->getBody(), true);

                        // get lat
                        $lat = @$array['latitude'];

                        // get lng
                        $lng = @$array['longitude'];

                        // check condition
                        if (!is_numeric($lat) OR !is_numeric($lng))
                        {
                            $bypass = 'yes';
                        }
                    }

                    // check condition
                    if ($bypass != 'yes')
                    {
                        //########################################
                        // xf_andy_members_map_data
                        //########################################
                        
                        // get lat
                        $pos1 = strpos($lat, '.');
                        $lat = substr($lat, 0, $pos1 + 2);
                        
                        // get lng
                        $pos1 = strpos($lng, '.');
                        $lng = substr($lng, 0, $pos1 + 2);
                        
                        // get result
                        $finder = \XF::finder('XF:User');
                        $result3 = $finder
                            ->where('user_id', $value1['user_id'])
                            ->fetchOne();
                        
                        // get userId
                        $userId = $value1['user_id'];
                        
                        // get username
                        $username = $result3['username'];

                        // save membersMapData
                        $membersMapData = \XF::em()->create('Andy\MembersMap:MembersMapData');
                        $membersMapData->user_id = $userId;
                        $membersMapData->username = $username;
                        $membersMapData->lat = $lat;
                        $membersMapData->lng = $lng;
                        $membersMapData->save();

                        //########################################
                        // xf_andy_members_map
                        //########################################
                        
                        // get results
                        $finder = \XF::finder('Andy\MembersMap:MembersMap');
                        $results4 = $finder
                            ->where('lat', $lat)
                            ->where('lng', $lng)
                            ->fetch();

                        // foreach condition
                        foreach ($results4 AS $result)
                        {
                            $result->delete();
                        }
                        
                        // get results2
                        $finder = \XF::finder('Andy\MembersMap:MembersMapData');
                        $results5 = $finder
                            ->where('lat', $lat)
                            ->where('lng', $lng)
                            ->order('username', 'ASC')
                            ->fetch();

                        // define variable
                        $info = '';

                        // for each results2
                        foreach ($results5 AS $value2)
                        {
                            // get member
                            $member = array(
                                'user_id' => $value2['user_id'],
                                'username' => $value2['username']
                            );

                            // get router
                            $router = \XF::app()->router('public');

                            // get link
                            $memberLink = $router->buildLink('members', $member);
                            
                            // check condition
                            if (!$showPrivate)
                            {
                                // check condition
                                if ($addBaseUrl)
                                {
                                    // get info
                                    $info = $info . '<a href="' . $location . $memberLink . '">' . $value2['username'] . '</a><br />';
                                }
                                else
                                {
                                    $info = $info . '<a href="' . $memberLink . '">' . $value2['username'] . '</a><br />';
                                }
                            }
                            
                            // check condition
                            if ($showPrivate)
                            {
                                // get info
                                $info = $info . $phrase . '<br />';
                            }
                        }
                        
                        // save membersMapData
                        $membersMap = \XF::em()->create('Andy\MembersMap:MembersMap');
                        $membersMap->lat = $lat;
                        $membersMap->lng = $lng;
                        $membersMap->info = $info;
                        $membersMap->save();
                    }
                }
			}
		}
	}
}